==> libsyncml_0.4.6.orig.tar.gz: libsyncml-0.4.6/config.h.cmake <==
/* config.h.cmake */

/* Bluetooth Transport */
#cmakedefine ENABLE_BLUETOOTH

/* Http Transport */
#cmakedefine ENABLE_HTTP

/* Obex Transport */
#cmakedefine ENABLE_OBEX

/* Tracing */
#cmakedefine ENABLE_TRACE

/* Defined if the correct libwbxml2 version exists. */
#cmakedefine ENABLE_WBXML

/* Define to 1 if you have the <dlfcn.h> header file. */
#cmakedefine HAVE_DLFCN_H 1

/* Define to 1 if you have the <inttypes.h> header file. */
#cmakedefine HAVE_INTTYPES_H 1

/* Define to 1 if you have the <memory.h> header file. */
#cmakedefine HAVE_MEMORY_H 1

/* Define to 1 if you have the <stdint.h> header file. */
#cmakedefine HAVE_STDINT_H 1

/* Define to 1 if you have the <stdlib.h> header file. */
#cmakedefine HAVE_STDLIB_H 1

/* Define to 1 if you have the <strings.h> header file. */
#cmakedefine HAVE_STRINGS_H 1

/* Define to 1 if you have the <string.h> header file. */
#cmakedefine HAVE_STRING_H 1

/* Define to 1 if you have the <sys/stat.h> header file. */
#cmakedefine HAVE_SYS_STAT_H 1

/* Define to 1 if you have the <sys/types.h> header file. */
#cmakedefine HAVE_SYS_TYPES_H 1

/* Define to 1 if the system has the type `uint16_t'. */
#cmakedefine HAVE_UINT16_T 1

/* Define to 1 if the system has the type `uint32_t'. */
#cmakedefine HAVE_UINT32_T 1

/* Define to 1 if the system has the type `uint8_t'. */
#cmakedefine HAVE_UINT8_T 1

/* Define to 1 if you have the <unistd.h> header file. */
#cmakedefine HAVE_UNISTD_H 1

/* Name of package */
#cmakedefine PACKAGE "${PACKAGE}"

/* Define to the address where bug reports for this package should be sent. */
#cmakedefine PACKAGE_BUGREPORT "${PACKAGE_BUGREPORT}"

/* Define to the full name of this package. */
#cmakedefine PACKAGE_NAME "${PACKAGE_NAME}"

/* Define to the full name and version of this package. */
#cmakedefine PACKAGE_STRING "${PACKAGE_STRING}"

/* Define to the one symbol short name of this package. */
#cmakedefine PACKAGE_TARNAME "${PACKAGE_TARNAME}"

/* Define to the version of this package. */
#cmakedefine PACKAGE_VERSION "${PACKAGE_VERSION}"

/* Define to 1 if you have the ANSI C header files. */
/* #undef STDC_HEADERS 1 */

/* Version number of package */
#cmakedefine VERSION "${VERSION}"

/* wbxml */
/* #undef WBXML_LIBS */

==> libsyncml_0.5.4.orig.tar.gz: libsyncml-0.5.4/config.h.cmake <==
/* config.h.cmake */

/* Bluetooth Transport */
#cmakedefine ENABLE_BLUETOOTH

/* Bluetooth SDP library - necessary for automatic channel discovery */
#cmakedefine ENABLE_BLUETOOTH_SDPLIB

/* Http Transport */
#cmakedefine ENABLE_HTTP

/* libsoup version in use */
#cmakedefine HAVE_LIBSOUP22_SOLARIS
#cmakedefine HAVE_LIBSOUP22
#cmakedefine HAVE_LIBSOUP24

/* Obex Transport */
#cmakedefine ENABLE_OBEX

/* Obex Transport via TCP */
/* TODO: Remove this on next OpenOBEX */
#cmakedefine ENABLE_OPENOBEX_TCP

/* Tracing */
#cmakedefine ENABLE_TRACE

/* Defined if the correct libwbxml2 version exists. */
#cmakedefine ENABLE_WBXML

/* Define to 1 if you have the <dlfcn.h> header file. */
#cmakedefine HAVE_DLFCN_H 1

/* Define to 1 if you have the <inttypes.h> header file. */
#cmakedefine HAVE_INTTYPES_H 1

/* Define to 1 if you have the <memory.h> header file. */
#cmakedefine HAVE_MEMORY_H 1

/* Define to 1 if you have the <stdint.h> header file. */
#cmakedefine HAVE_STDINT_H 1

/* Define to 1 if you have the <stdlib.h> header file. */
#cmakedefine HAVE_STDLIB_H 1

/* Define to 1 if you have the <strings.h> header file. */
#cmakedefine HAVE_STRINGS_H 1

/* Define to 1 if you have the <string.h> header file. */
#cmakedefine HAVE_STRING_H 1

/* Define to 1 if you have the <sys/stat.h> header file. */
#cmakedefine HAVE_SYS_STAT_H 1

/* Define to 1 if you have the <sys/types.h> header file. */
#cmakedefine HAVE_SYS_TYPES_H 1

/* Define to 1 if the system has the type `uint16_t'. */
#cmakedefine HAVE_UINT16_T 1

/* Define to 1 if the system has the type `uint32_t'. */
#cmakedefine HAVE_UINT32_T 1

/* Define to 1 if the system has the type `uint8_t'. */
#cmakedefine HAVE_UINT8_T 1

/* Define to 1 if you have the <unistd.h> header file. */
#cmakedefine HAVE_UNISTD_H 1

/* Name of package */
#cmakedefine PACKAGE "${PACKAGE}"

/* Define to the address where bug reports for this package should be sent. */
#cmakedefine PACKAGE_BUGREPORT "${PACKAGE_BUGREPORT}"

/* Define to the full name of this package. */
#cmakedefine PACKAGE_NAME "${PACKAGE_NAME}"

/* Define to the full name and version of this package. */
#cmakedefine PACKAGE_STRING "${PACKAGE_STRING}"

/* Define to the one symbol short name of this package. */
#cmakedefine PACKAGE_TARNAME "${PACKAGE_TARNAME}"

/* Define to the version of this package. */
#cmakedefine PACKAGE_VERSION "${PACKAGE_VERSION}"

/* Define to the SONAME libversion of this package. */
#cmakedefine PACKAGE_SONAME "${PACKAGE_SONAME}"

/* Define to 1 if you have the ANSI C header files. */
/* #undef STDC_HEADERS 1 */

/* Version number of package */
#cmakedefine VERSION "${VERSION}"

/* wbxml */
/* #undef WBXML_LIBS */
